@@ -108,14 +108,17 @@ _e_fm_main_eeze_format_error_msg(char     **buf,
    char *tmp;
 
    vu = strlen(v->udi) + 1;
-   vm = strlen(v->mount_point) + 1;
+   vm = (v->mount_point ? strlen(v->mount_point) : 0) + 1;
    en = strlen(name) + 1;
    size = vu + vm + en + strlen(msg) + 1;
    tmp = *buf = malloc(size);
 
    strcpy(tmp, v->udi);
    tmp += vu;
-   strcpy(tmp, v->mount_point);
+   if (v->mount_point)
+     strcpy(tmp, v->mount_point);
+   else
+     tmp[0] = 0;
    tmp += vm;
    strcpy(tmp, name);
    tmp += en;
@@ -241,7 +244,8 @@ _e_fm_main_eeze_cb_vol_unmounted(void *user_data EINA_UNUSED,
    v->mounted = EINA_FALSE;
    INF("UNMOUNT: %s from %s", v->udi, v->mount_point);
    if (!strncmp(v->mount_point, e_user_dir_get(), strlen(e_user_dir_get())))
-     unlink(v->mount_point);
+     if (unlink(v->mount_point))
+       printf("Error unlinking mount point!\n");
    size = strlen(v->udi) + 1 + strlen(v->mount_point) + 1;
    buf = alloca(size);
    strcpy(buf, v->udi);
@@ -404,18 +408,19 @@ _e_fm_main_eeze_volume_add(const char *syspath,
         v->partition_label = eeze_disk_udev_get_property(v->disk, "ID_FS_LABEL");
      }
 
-   /* if we have dev/sda ANd dev/sda1 - ia a parent vol - del the parent vol
-    * since we actually have real child partition volumes to mount */
-   if ((v->partition != 0) && (v->parent))
+   if (v->parent)
      {
-        E_Volume *v2 = _e_fm_main_eeze_volume_find_fast(v->parent);
-        
-        if ((v2) && (v2->partition == 0))
-          _e_fm_main_eeze_volume_del(v2->udi);
-     }
+        E_Storage *s;
+
+        if (v->partition)
+          {
+             /* prevent having storage and volume from same device */
+             E_Volume *v2 = _e_fm_main_eeze_volume_find_fast(v->parent);
+
+             if ((v2) && (v2->partition == 0))
+               _e_fm_main_eeze_volume_del(v2->udi);
+          }
    
-   {
-      E_Storage *s;
       s = e_storage_find(v->parent);
       INF("++VOL:\n  syspath: %s\n  uuid: %s\n  fstype: %s\n  size: %llu\n label: %s\n"
           "  partition: %d\n  partition_number: %d\n partition_label: %s\n  mounted: %d\n  mount_point: %s",
@@ -423,7 +428,7 @@ _e_fm_main_eeze_volume_add(const char *syspath,
           v->partition ? v->partition_label : "(not a partition)", v->mounted, v->mount_point);
       if (s)
         v->storage = s;
-      else if (v->parent)
+      else
         s = v->storage = _e_fm_main_eeze_storage_add(v->parent);
 
       if (s)
