@@ -399,7 +399,7 @@ config_luncher(E_Zone *zone, Instance *inst, Eina_Bool bar)
    elm_slider_indicator_format_set(slider, "%1.0f");
    elm_slider_min_max_set(slider, 1, 256);
    elm_slider_value_set(slider, inst->cfg->preview_size);
-   elm_slider_step_set(slider, 1);
+   elm_slider_step_set(slider, 1 /  256.0);
    elm_slider_span_size_set(slider, 256);
    E_ALIGN(slider, 0.0, 0.0);
    E_WEIGHT(slider, EVAS_HINT_EXPAND, 0);
